==> nextcloud-app-mail-4.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/lv.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Iegultais ziņojums%s",
    "Important mail" : "Svarīgs pasts",
    "Important" : "Svarīgi",
    "Work" : "Darbs",
    "Personal" : "Personīgs",
    "Later" : "Vēlāk",
    "Mail" : "E-pasts",
    "Mails" : "E-pasta sūtījumi",
    "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
    "Auto" : "Automātiski",
    "Name" : "Nosaukums",
    "Mail address" : "E-pasta adrese",
    "Password" : "Parole",
    "Manual" : "Manuāli",
    "IMAP Settings" : "IMAP iestatījumi",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP drošība",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Settings" : "SMTP iestatījumi",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP drošība",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Connecting" : "Savienojuma izveide",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Password required" : "Nepieciešama parole",
    "Account settings" : "Konta iestatījumi",
    "Aliases" : "Aizstājvārdi",
    "Signature" : "Paraksts",
    "Go back" : "Atpakaļ",
    "Email address" : "E-pasta adrese",
    "Cancel" : "Atcelt",
    "Accounts" : "Konti",
    "Add mail account" : "Pievienot e-pasta kontu",
    "General" : "Vispārīgs",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Archive" : "Arhīvi",
    "Delete" : "Dzēst",
    "Search" : "Meklēt",
    "Send" : "Sūtīt",
    "Refresh" : "Atsvaidzināt",
    "Select account" : "Izvēlieties kontu",
    "Subject" : "Temats",
    "Write message …" : "Rakstiet ziņu...",
    "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
    "Enter a date" : "Ievadiet datumu",
    "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
    "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
    "Choose" : "Izvēlies",
    "Confirm" : "Apstiprināt",
    "Favorite" : "Favorīts",
    "Read" : "Lasīt",
    "Unselect" : "Noņemt atlasi",
    "Select" : "Atzīmēt",
    "Edit tags" : "Labot birkas",
    "Back" : "Atpakaļ",
    "Create event" : "Izveidot notikumu",
    "Forward" : "Turpināt",
    "Load more" : "Ielādēt vairāk",
    "All day" : "Visas dienas",
    "Description" : "Apraksts",
    "Create" : "Izveidot",
    "Comment" : "Piebilde",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "Remove" : "Noņemt",
    "email" : "e-pasts",
    "Other" : "Cits",
    "View source" : "Skatīt avotu",
    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
    "Import into calendar" : "Importēt kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Unnamed" : "Nenosaukts",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tika aizturēti, lai aizsargātu Tavu privātumu.",
    "Show images" : "Parādīt attēlus",
    "Show images temporarily" : "Īslaicīgi parādīt attēlus",
    "Move" : "Pārvietot",
    "Quota" : "Kvota",
    "Saving" : "Saglabā",
    "Remove account" : "Noņemt kontu",
    "Loading …" : "Ielādē…",
    "Rename" : "Pārsaukt",
    "Subscribed" : "Abonēts",
    "New message" : "Jauna ziņa",
    "Retry" : "Mēģināt vēlreiz",
    "Sending …" : "Sūta …",
    "Reply" : "Atbildēt",
    "Message" : "Ziņojums",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Add" : "Pievienot",
    "Search in mailbox" : "Meklēt pastkastē",
    "Close" : "Aizvērt",
    "Date" : "Datums",
    "Tags" : "Birkas",
    "Select tags" : "Izvēlies birkas",
    "Clear" : "Notīrīt",
    "Custom" : "Pielāgots",
    "Delete tag" : "Dzēst atzīmi",
    "Tag already exists" : "Birka jau pastāv",
    "Not found" : "Nav atrasts",
    "Untitled event" : "Nenosaukts notikums",
    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
    "Reset" : "Atiestatīt",
    "Client ID" : "Klienta ID",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Valid until" : "Derīgs līdz",
    "Certificate" : "Sertifikāts",
    "Submit" : "Iesniegt",
    "Connect your mail account" : "Pievienot savu e-pasta kontu",
    "All" : "Visi",
    "Drafts" : "Melnraksti",
    "Favorites" : "Favorīti",
    "All inboxes" : "Visas iesūtnes",
    "Inbox" : "Iesūtne",
    "Junk" : "Nevēlams",
    "Sent" : "Izsūtne",
    "Trash" : "Miskaste",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "Continue to %s" : "Turpināt %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-mail-4.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/lv.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Iegultais ziņojums%s",
    "Important mail" : "Svarīgs pasts",
    "Important" : "Svarīgi",
    "Work" : "Darbs",
    "Personal" : "Personīgs",
    "Later" : "Vēlāk",
    "Mail" : "E-pasts",
    "Mails" : "E-pasta sūtījumi",
    "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
    "Auto" : "Automātiski",
    "Name" : "Nosaukums",
    "Mail address" : "E-pasta adrese",
    "Password" : "Parole",
    "Manual" : "Manuāli",
    "IMAP Settings" : "IMAP iestatījumi",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP drošība",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Settings" : "SMTP iestatījumi",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP drošība",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Connecting" : "Savienojuma izveide",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Password required" : "Nepieciešama parole",
    "Account settings" : "Konta iestatījumi",
    "Aliases" : "Aizstājvārdi",
    "Signature" : "Paraksts",
    "Filters" : "Filtri",
    "Go back" : "Atpakaļ",
    "Email address" : "E-pasta adrese",
    "Cancel" : "Atcelt",
    "Accounts" : "Konti",
    "Add mail account" : "Pievienot e-pasta kontu",
    "General" : "Vispārīgs",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Archive" : "Arhīvi",
    "Delete" : "Dzēst",
    "Search" : "Meklēt",
    "Send" : "Sūtīt",
    "Refresh" : "Atsvaidzināt",
    "Select account" : "Izvēlieties kontu",
    "Subject" : "Temats",
    "Write message …" : "Rakstiet ziņu...",
    "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
    "Enter a date" : "Ievadiet datumu",
    "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
    "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
    "Choose" : "Izvēlies",
    "Confirm" : "Apstiprināt",
    "Favorite" : "Izlasē",
    "Read" : "Lasīt",
    "Unselect" : "Noņemt atlasi",
    "Select" : "Atzīmēt",
    "Edit tags" : "Labot birkas",
    "Back" : "Atpakaļ",
    "Create event" : "Izveidot notikumu",
    "Forward" : "Turpināt",
    "Load more" : "Ielādēt vairāk",
    "All day" : "Visas dienas",
    "Description" : "Apraksts",
    "Create" : "Izveidot",
    "Comment" : "Piebilde",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "More options" : "Vairāk opciju",
    "Remove" : "Noņemt",
    "email" : "e-pasts",
    "Other" : "Cits",
    "View source" : "Skatīt avotu",
    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
    "Import into calendar" : "Importēt kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Unnamed" : "Nenosaukts",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tika aizturēti, lai aizsargātu Tavu privātumu.",
    "Show images" : "Parādīt attēlus",
    "Show images temporarily" : "Īslaicīgi parādīt attēlus",
    "Move" : "Pārvietot",
    "Quota" : "Kvota",
    "Saving" : "Saglabā",
    "Remove account" : "Noņemt kontu",
    "Loading …" : "Ielādē…",
    "Rename" : "Pārsaukt",
    "Subscribed" : "Abonēts",
    "New message" : "Jauna ziņa",
    "Retry" : "Mēģināt vēlreiz",
    "Sending …" : "Sūta …",
    "Reply" : "Atbildēt",
    "Message" : "Ziņojums",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Add" : "Pievienot",
    "Search in mailbox" : "Meklēt pastkastē",
    "Close" : "Aizvērt",
    "Date" : "Datums",
    "Tags" : "Birkas",
    "Select tags" : "Izvēlies birkas",
    "Clear" : "Notīrīt",
    "Custom" : "Pielāgots",
    "Delete tag" : "Dzēst atzīmi",
    "Tag already exists" : "Birka jau pastāv",
    "Not found" : "Nav atrasts",
    "Untitled event" : "Nenosaukts notikums",
    "Operator" : "Operators",
    "Actions" : "Darbības",
    "Priority" : "Prioritāte",
    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
    "Reset" : "Atiestatīt",
    "Client ID" : "Klienta ID",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Valid until" : "Derīgs līdz",
    "Certificate" : "Sertifikāts",
    "Submit" : "Iesniegt",
    "Connect your mail account" : "Pievienot savu e-pasta kontu",
    "All" : "Visi",
    "Drafts" : "Melnraksti",
    "Favorites" : "Izlases vienumi",
    "All inboxes" : "Visas iesūtnes",
    "Inbox" : "Iesūtne",
    "Junk" : "Nevēlams",
    "Sent" : "Izsūtne",
    "Trash" : "Miskaste",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "Continue to %s" : "Turpināt %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
